Struct Awhtr
#[repr(transparent)]pub struct Awhtr(pub u32);Tuple Fields
0: u32Implementations
impl Awhtr
impl Awhtr
pub const fn bkawh(&self) -> u8
pub const fn bkawh(&self) -> u8
Break signal assignment to analog watchdog high threshold event BKAWH[i] = 0: Break i signal is not assigned to an analog watchdog high threshold event BKAWH[i] = 1: Break i signal is assigned to an analog watchdog high threshold event.
pub const fn set_bkawh(&mut self, val: u8)
pub const fn set_bkawh(&mut self, val: u8)
Break signal assignment to analog watchdog high threshold event BKAWH[i] = 0: Break i signal is not assigned to an analog watchdog high threshold event BKAWH[i] = 1: Break i signal is assigned to an analog watchdog high threshold event.
pub const fn awht(&self) -> u32
pub const fn awht(&self) -> u32
Analog watchdog high threshold These bits are written by software to define the high threshold for the analog watchdog. Note: In case channel transceivers monitor (AWFSEL=1), the higher 16 bits (AWHT[23:8]) define the 16-bit threshold as compared with the analog watchdog filter output (because data coming from the analog watchdog filter are up to a 16-bit resolution). Bits AWHT[7:0] are not taken into comparison in this case.
pub const fn set_awht(&mut self, val: u32)
pub const fn set_awht(&mut self, val: u32)
Analog watchdog high threshold These bits are written by software to define the high threshold for the analog watchdog. Note: In case channel transceivers monitor (AWFSEL=1), the higher 16 bits (AWHT[23:8]) define the 16-bit threshold as compared with the analog watchdog filter output (because data coming from the analog watchdog filter are up to a 16-bit resolution). Bits AWHT[7:0] are not taken into comparison in this case.