stm32-metapac

Crates

git

Versions

stm32f413rh

Flavors

Cr1

Struct Cr1 

#[repr(transparent)]
pub struct Cr1(pub u32);

Tuple Fields

0: u32

Implementations



impl Cr1

pub const fn dfen(&self) -> bool

DFSDM_FLTx enable Data which are cleared by setting DFEN=0: register DFSDM_FLTxISR is set to the reset state register DFSDM_FLTxAWSR is set to the reset state.

pub const fn set_dfen(&mut self, val: bool)

DFSDM_FLTx enable Data which are cleared by setting DFEN=0: register DFSDM_FLTxISR is set to the reset state register DFSDM_FLTxAWSR is set to the reset state.

pub const fn jswstart(&self) -> bool

Start a conversion of the injected group of channels This bit is always read as ‘0’.

pub const fn set_jswstart(&mut self, val: bool)

Start a conversion of the injected group of channels This bit is always read as ‘0’.

pub const fn jsync(&self) -> bool

Launch an injected conversion synchronously with the DFSDM_FLT0 JSWSTART trigger This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn set_jsync(&mut self, val: bool)

Launch an injected conversion synchronously with the DFSDM_FLT0 JSWSTART trigger This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn jscan(&self) -> bool

Scanning conversion mode for injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). Writing JCHG if JSCAN=0 resets the channel selection to the lowest selected channel.

pub const fn set_jscan(&mut self, val: bool)

Scanning conversion mode for injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). Writing JCHG if JSCAN=0 resets the channel selection to the lowest selected channel.

pub const fn jdmaen(&self) -> bool

DMA channel enabled to read data for the injected channel group This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn set_jdmaen(&mut self, val: bool)

DMA channel enabled to read data for the injected channel group This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn jextsel(&self) -> u8

Trigger signal selection for launching injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). Note: synchronous trigger has latency up to one fDFSDMCLK clock cycle (with deterministic jitter), asynchronous trigger has latency 2-3 fDFSDMCLK clock cycles (with jitter up to 1 cycle). DFSDM_FLTx 0x00 dfsdm_jtrg0 0x01 dfsdm_jtrg1 … 0x1E dfsdm_jtrg30 0x1F dfsdm_jtrg31 Refer to . 0x0-0x1F: Trigger inputs selected by the following table (internal or external trigger).

pub const fn set_jextsel(&mut self, val: u8)

Trigger signal selection for launching injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). Note: synchronous trigger has latency up to one fDFSDMCLK clock cycle (with deterministic jitter), asynchronous trigger has latency 2-3 fDFSDMCLK clock cycles (with jitter up to 1 cycle). DFSDM_FLTx 0x00 dfsdm_jtrg0 0x01 dfsdm_jtrg1 … 0x1E dfsdm_jtrg30 0x1F dfsdm_jtrg31 Refer to . 0x0-0x1F: Trigger inputs selected by the following table (internal or external trigger).

pub const fn jexten(&self) -> u8

Trigger enable and trigger edge selection for injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn set_jexten(&mut self, val: u8)

Trigger enable and trigger edge selection for injected conversions This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn rswstart(&self) -> bool

Software start of a conversion on the regular channel This bit is always read as ‘0’.

pub const fn set_rswstart(&mut self, val: bool)

Software start of a conversion on the regular channel This bit is always read as ‘0’.

pub const fn rcont(&self) -> bool

Continuous mode selection for regular conversions Writing ‘0’ to this bit while a continuous regular conversion is already in progress stops the continuous mode immediately.

pub const fn set_rcont(&mut self, val: bool)

Continuous mode selection for regular conversions Writing ‘0’ to this bit while a continuous regular conversion is already in progress stops the continuous mode immediately.

pub const fn rsync(&self) -> bool

Launch regular conversion synchronously with DFSDM_FLT0 This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn set_rsync(&mut self, val: bool)

Launch regular conversion synchronously with DFSDM_FLT0 This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn rdmaen(&self) -> bool

DMA channel enabled to read data for the regular conversion This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn set_rdmaen(&mut self, val: bool)

DMA channel enabled to read data for the regular conversion This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1).

pub const fn rch(&self) -> u8

Regular channel selection … 7: Channel 7 is selected as the regular channel Writing these bits when RCIP=1 takes effect when the next regular conversion begins. This is especially useful in continuous mode (when RCONT=1). It also affects regular conversions which are pending (due to ongoing injected conversion).

pub const fn set_rch(&mut self, val: u8)

Regular channel selection … 7: Channel 7 is selected as the regular channel Writing these bits when RCIP=1 takes effect when the next regular conversion begins. This is especially useful in continuous mode (when RCONT=1). It also affects regular conversions which are pending (due to ongoing injected conversion).

pub const fn fast(&self) -> bool

Fast conversion mode selection for regular conversions When converting a regular conversion in continuous mode, having enabled the fast mode causes each conversion (except the first) to execute faster than in standard mode. This bit has no effect on conversions which are not continuous. This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). if FAST=0 (or first conversion in continuous mode if FAST=1): t = [FOSR * (IOSR-1 + FORD) + FORD] / fCKIN ….. for Sincx filters t = [FOSR * (IOSR-1 + 4) + 2] / fCKIN ….. for FastSinc filter if FAST=1 in continuous mode (except first conversion): t = [FOSR * IOSR] / fCKIN in case if FOSR = FOSR[9:0]+1 = 1 (filter bypassed, active only integrator): t = IOSR / fCKIN (… but CNVCNT=0) where: fCKIN is the channel input clock frequency (on given channel CKINy pin) or input data rate in case of parallel data input.

pub const fn set_fast(&mut self, val: bool)

Fast conversion mode selection for regular conversions When converting a regular conversion in continuous mode, having enabled the fast mode causes each conversion (except the first) to execute faster than in standard mode. This bit has no effect on conversions which are not continuous. This bit can be modified only when DFEN=0 (DFSDM_FLTxCR1). if FAST=0 (or first conversion in continuous mode if FAST=1): t = [FOSR * (IOSR-1 + FORD) + FORD] / fCKIN ….. for Sincx filters t = [FOSR * (IOSR-1 + 4) + 2] / fCKIN ….. for FastSinc filter if FAST=1 in continuous mode (except first conversion): t = [FOSR * IOSR] / fCKIN in case if FOSR = FOSR[9:0]+1 = 1 (filter bypassed, active only integrator): t = IOSR / fCKIN (… but CNVCNT=0) where: fCKIN is the channel input clock frequency (on given channel CKINy pin) or input data rate in case of parallel data input.

pub const fn awfsel(&self) -> bool

Analog watchdog fast mode select.

pub const fn set_awfsel(&mut self, val: bool)

Analog watchdog fast mode select.