stm32-metapac

Crates

git

Versions

stm32f413rh

Flavors

Dlyr

Struct Dlyr 

#[repr(transparent)]
pub struct Dlyr(pub u32);

Tuple Fields

0: u32

Implementations



impl Dlyr

pub const fn plsskp(&self) -> u8

Pulses to skip for input data skipping function immediately after writing to this field. Reading of PLSSKP[5:0] returns current value of pulses which will be skipped. If PLSSKP[5:0]=0 then all required data samples were already skipped. Note: User can update PLSSKP[5:0] also when PLSSKP[5:0] is not zero. 0-63: Defines the number of serial input samples that will be skipped. Skipping is applied.

pub const fn set_plsskp(&mut self, val: u8)

Pulses to skip for input data skipping function immediately after writing to this field. Reading of PLSSKP[5:0] returns current value of pulses which will be skipped. If PLSSKP[5:0]=0 then all required data samples were already skipped. Note: User can update PLSSKP[5:0] also when PLSSKP[5:0] is not zero. 0-63: Defines the number of serial input samples that will be skipped. Skipping is applied.